# eric7.Plugins.VcsPlugins.vcsGit.GitStatusMonitorThread

Module implementing the VCS status monitor thread class for Git.

### Global Attributes

None

### Classes

GitStatusMonitorThread | Class implementing the VCS status monitor thread class for Git.

### Functions

None

## GitStatusMonitorThread

Class implementing the VCS status monitor thread class for Git.

### Derived from

VcsStatusMonitorThread

### Class Attributes

ConflictStates

### Class Methods

None

### Methods

GitStatusMonitorThread | Constructor
_getInfo | Protected method implementing the real info action.
_performMonitor | Protected method implementing the monitoring action.
_shutdown | Protected method performing shutdown actions.

### Static Methods

None

#### GitStatusMonitorThread (Constructor)

GitStatusMonitorThread(interval, project, vcs, parent=None)

Constructor

interval (int)
  new interval in seconds
project (Project)
  reference to the project object
vcs (Git)
  reference to the version control object
parent (QObject)
  reference to the parent object

#### GitStatusMonitorThread._getInfo

_getInfo()

Protected method implementing the real info action.

This method should be overridden and create a short info message to be shown in the main window status bar right next to the status indicator.

Return:
  short info message

Return Type:
  str

#### GitStatusMonitorThread._performMonitor

_performMonitor()

Protected method implementing the monitoring action.

This method populates the statusList member variable with a list of strings giving the status in the first column and the path relative to the project directory starting with the third column. The allowed status flags are:

- "A" path was added but not yet committed
- "M" path has local changes
- "O" path was removed
- "R" path was deleted and then re-added
- "U" path needs an update
- "Z" path contains a conflict
- "?" path is not tracked
- "!" path is missing
- " " path is back at normal

Return:
  tuple of flag indicating successful operation and a status message in case of non successful operation

Return Type:
  tuple of (bool, str)

#### GitStatusMonitorThread._shutdown

_shutdown()

Protected method performing shutdown actions.

Up